@@ -1,11 +1,17 @@
 from mypy.route_render import route,render_func
 
+
 @route.index
 @render_func
 def index():
-    pass
+    G.name = {
+        1:1,
+        2:2,
+        3:3,
+    }
 
 
 @route.login
 def login():
+
     return "Yx"
\ No newline at end of file
